#!/usr/bin/env python3

BCDN_FILE_PATH_TEMPLATE = './bcdn_supp_log/{data}.bcdn-atomic.a2.s0.t{thread}.b{bundle_size}'
NPCD_FILE_PATH_TEMPLATE = './bcdn_supp_log/{data}.liblr.s6.t{thread}'
NPCD_NOTRICK_FILE_PATH_TEMPLATE = './bcdn_supp_log/{data}.liblr-no-trick.s6.t{thread}'

def parse_line(line):
    if line.startswith('*'):
        line = line[2:]
    if not line.startswith('iter'):
        return None

    tokens = line.strip().split()

    d = {}
    for i, token in enumerate(tokens):
        if i % 2 == 0:
            key = token
        else:
            d[key] = float(token)

    d['iter'] += 1

    return d

def parse_bcdn_file(data, thread, bundle_size):
    filepath = BCDN_FILE_PATH_TEMPLATE.format(data=data, thread=thread, bundle_size=bundle_size)
    with open(filepath + '.parsed', 'w') as out:
        for line in open(filepath):
            d = parse_line(line)
            if d is None:
                continue
            out.write('{0} {1}\n'.format(d['time'], d['f']))

def parse_npcd_file(data, thread):
    filepath = NPCD_FILE_PATH_TEMPLATE.format(data=data, thread = thread)
    with open(filepath + '.parsed', 'w') as out:
        for line in open(filepath):
            if 'time_solve_d' in line:
                line = line.strip().split()
                time = float(line[5].split(',')[0])
                obj = float(line[-1])
                out.write('{0} {1}\n'.format(time, obj))

def parse_npcd_notrick_file(data, thread):
    filepath = NPCD_NOTRICK_FILE_PATH_TEMPLATE.format(data=data, thread = thread)
    with open(filepath + '.parsed', 'w') as out:
        for line in open(filepath):
            if 'time_solve_d' in line:
                line = line.strip().split()
                time = float(line[5].split(',')[0])
                obj = float(line[-1])
                out.write('{0} {1}\n'.format(time, obj))

parse_bcdn_file('kdda', 8, 29500)
parse_npcd_file('kdda', 8)
parse_npcd_notrick_file('kdda', 8)
parse_bcdn_file('url', 8, 5000)
parse_npcd_file('url', 8)
parse_bcdn_file('higgs', 8, 8)
parse_npcd_file('higgs', 8)
