#!/usr/bin/env python3

import sys, subprocess

cores_list_1 = [8, 1]
cores_list_2 = [4, 2]

if int(sys.argv[1]) == -1:
    data_list = ['heart_scale']
elif int(sys.argv[1]) == 0:
    data_list = ['rcv1_test']
else:
    data_list = ['kdda', 'kdd12', 'eps', 'avazu-app', 'higgs', 'url', 'criteo', 'web_trigram', 'split_site_t_0_1', 'rcv1_test']

datas_path_dict = {\
'heart_scale':'./data/heart_scale', \
'criteo':'./data/criteo.tr.svm', \
'rcv1_test':'./data/rcv1_test', \
'yk':'./data/leisure', \
'eps':'./data/epsilon_normalized', \
'higgs':'./data/HIGGS', \
'kdd12':'./data/kdd12', \
'url':'./data/url_combined', \
'web_trigram':'./data/webspam_wc_normalized_trigram',\
'avazu-app':'./data/avazu-app',\
'kdda':'./data/kdda',\
'split_site_t_0_1':'./data/split_site.t.0.1'
}

method_path_dict = {\
'cdn_svm_nonshrink':'./codes/npcd-nonshrink',\
'cdn_svm':'./codes/npcd',\
'shotgun_svm':'./codes/liblinear-2.11-shotgun/',
'shotgun_svm_long':'./codes/liblinear-2.11-shotgun-long/',
'bcdn_svm':'./codes/ParallelCDN-master',
'cdn_lr_nonshrink':'./codes/liblinear-1.7-omp-nonshrink/',
'cdn_lr':'./codes/liblinear-1.7-omp',
'bcdn_lr':'./codes/ParallelCDN-master',
'shotgun_lr':'./codes/liblinear-1.7-shotgun',
'shotgun_lr_long':'./codes/liblinear-1.7-shotgun-long',
}

data_need_more_run_list = ['url-shotgun_svm', 'url-shotgun_lr', 'kdd12-shotgun_lr']

bundle_size_dict = {\
'kdda-bcdn_svm':95000,\
'kdda-bcdn_lr':29500,\
}

methods_list = ['shotgun_lr', 'shotgun_svm', 'cdn_svm', 'cdn_lr', 'bcdn_lr', 'bcdn_svm', 'cdn_svm_nonshrink', 'cdn_lr_nonshrink']

def run(cmd):
    print(cmd)
    subprocess.call(cmd, shell=True)

log_dir_suffix = 'cdn.speedup.log'

def run_exp(core_list):
    for data in data_list:
        run('mkdir -p lr_logs/{data}.{suffix}'.format(data=data, suffix=log_dir_suffix))
        run('mkdir -p l2_logs/{data}.{suffix}'.format(data=data, suffix=log_dir_suffix))
        for core in core_list:
            for method in methods_list:
                if data + '-' + method in bundle_size_dict:
                    bundle_size = bundle_size_dict[data+'-'+method]
                else:
                    bundle_size = 10000

                if method == 'bcdn_svm':
                    if core == 1:
                        continue
                    else:
                        cmd = '{method_dir}/train -a 2 -s 1 -c {c} -t {num_threads} -b {bundle_size} {data_path} ./bcdn_dummy > l2_logs/{data}.{suffix}/{method}.{core}.log'.format(data_path=datas_path_dict[data], c=1, data=data, core=core, method_dir=method_path_dict[method], method=method, num_threads=core, suffix=log_dir_suffix, bundle_size = bundle_size)

                elif method == 'bcdn_lr':
                    if core == 1:
                        continue
                    else:
                        cmd = '{method_dir}/train -a 2 -s 0 -c {c} -t {num_threads} -b {bundle_size} {data_path} ./bcdn_dummy > lr_logs/{data}.{suffix}/{method}.{core}.log'.format(data_path=datas_path_dict[data], c=1, data=data, core=core, method_dir=method_path_dict[method], method=method, num_threads=core, suffix=log_dir_suffix, bundle_size = bundle_size)
                elif 'svm' in method:
                    if 'shotgun' in method and core ==1:
                        continue
                    else:
                        if data + '-' + method in data_need_more_run_list:
                            cmd = '{method_dir}/train -s 5 -c {c} -t {num_threads} {data_path} > l2_logs/{data}.{suffix}/{method}.{core}.log'.format(data_path=datas_path_dict[data], c=1, data=data, core=core, method_dir=method_path_dict[method + '_long'], method=method, num_threads=core, suffix=log_dir_suffix)
                        else:
                            cmd = '{method_dir}/train -s 5 -c {c} -t {num_threads} {data_path} > l2_logs/{data}.{suffix}/{method}.{core}.log'.format(data_path=datas_path_dict[data], c=1, data=data, core=core, method_dir=method_path_dict[method], method=method, num_threads=core, suffix=log_dir_suffix)
                elif 'lr' in method:
                    if 'shotgun' in method and core ==1:
                        continue
                    else:
                        if data + '-' + method in data_need_more_run_list:
                            cmd = '{method_dir}/train -s 6 -c {c} -t {num_threads} {data_path} > lr_logs/{data}.{suffix}/{method}.{core}.log'.format(data_path=datas_path_dict[data], c=1, data=data, core=core, method_dir=method_path_dict[method + '_long'], method=method, num_threads=core, suffix=log_dir_suffix)
                        else:
                            cmd = '{method_dir}/train -s 6 -c {c} -t {num_threads} {data_path} > lr_logs/{data}.{suffix}/{method}.{core}.log'.format(data_path=datas_path_dict[data], c=1, data=data, core=core, method_dir=method_path_dict[method], method=method, num_threads=core, suffix=log_dir_suffix)
                else:
                    continue
                run(cmd)

run_exp(cores_list_1)
run_exp(cores_list_2)
